@@ -5,10 +5,10 @@ import argparse
 import logging
 from datetime import datetime, timedelta
 
-__version_info__ = ('0', '0', '7')
+__version_info__ = ('0', '0', '8')
 __version__ = '.'.join(__version_info__)
 
-# from VideoTrackingWindowWindow import Ui_VideoTrackingWindowWindow
+from VideoTrackingWindow import Ui_VideoTrackingWindow
 from PyQt5 import QtCore, QtGui, QtWidgets, uic
 from PyQt5.QtCore import QDir, Qt, QUrl, pyqtSignal, QPoint, QRect, QObject
 from PyQt5.QtMultimedia import QMediaContent, QMediaPlayer, QVideoFrame, QAbstractVideoSurface, QAbstractVideoBuffer, QVideoSurfaceFormat, QVideoProbe
@@ -24,12 +24,13 @@ import numpy as np
 import cv2
 
 
-class VideoTrackingWindow(QMainWindow):
+class VideoTrackingWindow(QMainWindow, Ui_VideoTrackingWindow):
 
     def __init__(self, parent=None):
         super(VideoTrackingWindow, self).__init__(parent)
         # Load UI
-        uic.loadUi('VideoTrackingWindow.ui', self)
+        self.setupUi(self)
+        # uic.loadUi('VideoTrackingWindow.ui', self)
 
         # setup media player
         self.mediaPlayer = QMediaPlayer(None, QMediaPlayer.VideoSurface)
@@ -518,4 +519,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
